# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...voices.requests.sampling_params import SamplingParamsParams


class VoiceParams(typing_extensions.TypedDict):
    id: str
    sampling_params: typing_extensions.NotRequired[SamplingParamsParams]
    """
    Optional sampling params overrides. The defaults for this voice can be obtained through the [Voices](../voices/list#response.body.sampling_params) endpoint. See also [Sampling Params Guide](../tts/sampling-params-guide).
    """
